History
-------

This project was started in 2017 as a demo presented at the 40th International 
ACM SIGIR Conference on Research and Development in Information Retrieval in Tokyo (Japan).

People
------

The following people have been core contributors to rankeval's development and maintenance:

    * Claudio Lucchese - HPC-ISTI researcher - Pisa (Italy)
    * Franco Maria Nardini - HPC-ISTI researcher - Pisa (Italy)
    * Cristina Muntean - HPC-ISTI researcher - Pisa (Italy)
    * Salvatore Trani - HPC-ISTI researcher - Pisa (Italy)  

Please do not email the authors directly to ask for assistance or report issues.
Instead, please use GitHub issues or email to `rankeval@isti.cnr.it` for requests
and information.